@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2013 Zuza Software Foundation
@@ -23,6 +22,8 @@
 .. seealso:: http://en.wikipedia.org/wiki/Dzongkha_language
 """
 
+from __future__ import unicode_literals
+
 from translate.lang import common
 
 
