@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2008-2011 Zuza Software Foundation
@@ -32,28 +31,10 @@ you should checkout the following::
 It is not completely working, but it should give you a good start.
 """
 
-# xapian module versions before 1.0.13 hangs apache under mod_python
-import sys
 import re
-
-# detect if running under apache
-if 'apache' in sys.modules or '_apache' in sys.modules or 'mod_wsgi' in sys.modules:
-
-    def _str2version(version):
-        return [int(i) for i in version.split('.')]
-
-    import subprocess
-    # even checking xapian version leads to deadlock under apache, must figure version from command line
-    try:
-        command = subprocess.Popen(['xapian-check', '--version'], stdout=subprocess.PIPE)
-        stdout, stderr = command.communicate()
-        if _str2version(re.match('.*([0-9]+\.[0-9]+\.[0-9]+).*', stdout).groups()[0]) < [1, 0, 13]:
-            raise ImportError("Running under apache, can't load xapain")
-    except:
-        #FIXME: report is xapian-check command is missing?
-        raise ImportError("Running under apache, can't load xapian")
-
-import CommonIndexer
+import six
+import sys
+from . import CommonIndexer
 import xapian
 import os
 import time
@@ -97,7 +78,7 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
         """
         # call the __init__ function of our parent
         super(XapianDatabase, self).__init__(basedir, analyzer=analyzer,
-                create_allowed=create_allowed)
+                                             create_allowed=create_allowed)
         self.reader = None
         self.writer = None
         if os.path.exists(self.location):
@@ -106,8 +87,8 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
                 self.reader = xapian.Database(self.location)
             except xapian.DatabaseOpeningError as err_msg:
                 raise ValueError("Indexer: failed to open xapian database "
-                                 "(%s) - maybe it is not a xapian database: %s" % (
-                                 self.location, str(err_msg)))
+                                 "(%s) - maybe it is not a xapian database: %s" %
+                                 (self.location, str(err_msg)))
         else:
             # create a new database
             if not create_allowed:
@@ -120,11 +101,11 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
                     os.makedirs(parent_path)
             except IOError as err_msg:
                 raise OSError("Indexer: failed to create the parent "
-                              "directory (%s) of the indexing database: %s" % (
-                              parent_path, str(err_msg)))
+                              "directory (%s) of the indexing database: %s" %
+                              (parent_path, str(err_msg)))
             try:
                 self.writer = xapian.WritableDatabase(self.location,
-                        xapian.DB_CREATE_OR_OPEN)
+                                                      xapian.DB_CREATE_OR_OPEN)
                 self.flush()
             except xapian.DatabaseOpeningError as err_msg:
                 raise OSError("Indexer: failed to open or create a xapian "
@@ -156,17 +137,16 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
         """generate a query based on an existing query object
 
         basically this function should just create a copy of the original
+        Since query objects are immutable, this function is a no-op
 
         :param query: the original query object
         :type query: xapian.Query
         :return: the resulting query object
         :rtype: xapian.Query
         """
-        # create a copy of the original query
-        return xapian.Query(query)
+        return query
 
-    def _create_query_for_string(self, text, require_all=True,
-            analyzer=None):
+    def _create_query_for_string(self, text, require_all=True, analyzer=None):
         """generate a query for a plain term of a string query
 
         basically this function parses the string and returns the resulting
@@ -383,7 +363,7 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
         :rtype: list of dicts
         """
         result = []
-        if isinstance(fieldnames, basestring):
+        if isinstance(fieldnames, six.string_types):
             fieldnames = [fieldnames]
         try:
             self._walk_matches(query, _extract_fieldvalues,
@@ -394,28 +374,28 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
                                (result, fieldnames))
         return result
 
-    def _delete_stale_lock(self):
-        if not self._writer_is_open():
-            lockfile = os.path.join(self.location, 'flintlock')
-            if (os.path.exists(lockfile) and
-                (time.time() - os.path.getmtime(lockfile)) / 60 > 15):
-                logging.warning("Stale lock found in %s, removing.",
-                                self.location)
-                os.remove(lockfile)
-
     def _writer_open(self):
         """Open write access for the indexing database and acquire an
         exclusive lock.
         """
         if not self._writer_is_open():
-            self._delete_stale_lock()
             try:
                 self.writer = xapian.WritableDatabase(self.location, xapian.DB_OPEN)
+            except xapian.DatabaseLockError as err_msg:
+                # Do NOT delete the lock file - it's locked with fcntl()
+                # locking which the OS releases automatically when a
+                # process terminates so a "stale lock" is impossible.
+                # If it isn't in use, the failure will be some sort of
+                # system issue like running out of fds or processes.
+                raise ValueError("Indexer: failed to lock xapian database "
+                                 "(%s) for writing - it's probably in use "
+                                 "already: %s" %
+                                 (self.location, str(err_msg)))
             except xapian.DatabaseOpeningError as err_msg:
 
                 raise ValueError("Indexer: failed to open xapian database "
-                                 "(%s) - maybe it is not a xapian database: %s" % (
-                                 self.location, str(err_msg)))
+                                 "(%s) - maybe it is not a xapian database: %s" %
+                                 (self.location, str(err_msg)))
 
     def _writer_close(self):
         """close indexing write access and remove database lock"""
@@ -425,7 +405,7 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
 
     def _writer_is_open(self):
         """check if the indexing write access is currently open"""
-        return hasattr(self, "writer") and not self.writer is None
+        return hasattr(self, "writer") and self.writer is not None
 
     def _index_refresh(self):
         """re-read the indexer database"""
@@ -436,8 +416,8 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
                 self.reader.reopen()
         except xapian.DatabaseOpeningError as err_msg:
             raise ValueError("Indexer: failed to open xapian database "
-                             "(%s) - maybe it is not a xapian database: %s" % (
-                             self.location, str(err_msg)))
+                             "(%s) - maybe it is not a xapian database: %s" %
+                             (self.location, str(err_msg)))
 
 
 class XapianEnquire(CommonIndexer.CommonEnquire):
@@ -488,7 +468,7 @@ def _truncate_term_length(term, taken=0):
         return term
 
 
-def _extract_fieldvalues(match, (result, fieldnames)):
+def _extract_fieldvalues(match, result_and_fieldnames):
     """Add a dict of field values to a list.
 
     Usually this function should be used together with :func:`_walk_matches`
@@ -501,15 +481,17 @@ def _extract_fieldvalues(match, (result, fieldnames)):
     :param fieldnames: the names of the fields to be added to the dict
     :type fieldnames: list of str
     """
+    result, fieldnames = result_and_fieldnames
     # prepare empty dict
     item_fields = {}
     # fill the dict
     for term in match["document"].termlist():
         for fname in fieldnames:
-            if ((fname is None) and re.match("[^A-Z]", term.term)):
-                value = term.term
-            elif re.match("%s[^A-Z]" % str(fname).upper(), term.term):
-                value = term.term[len(fname):]
+            termstr = term.term.decode('utf-8')
+            if ((fname is None) and re.match("[^A-Z]", termstr)):
+                value = termstr
+            elif re.match("%s[^A-Z]" % str(fname).upper(), termstr):
+                value = termstr[len(fname):]
             else:
                 continue
             # we found a matching field/term
