@@ -34,8 +34,8 @@ from translate.misc.multistring import multistring
 from babel.core import Locale, UnknownLocaleError
 
 EOF = None
-WHITESPACE = ' \t'  # Whitespace that we collapse.
-MULTIWHITESPACE = re.compile('[ \t]{2}')
+WHITESPACE = ' \n\t'  # Whitespace that we collapse.
+MULTIWHITESPACE = re.compile('[ \n\t]{2}(?!\\\\n)')
 
 
 @six.python_2_unicode_compatible
@@ -81,7 +81,7 @@ class AndroidResourceUnit(base.TranslationUnit):
     def getcontext(self):
         return self.xmlelement.get("name")
 
-    def unescape(self, text):
+    def unescape(self, text, strip=True):
         """
         Remove escaping from Android resource.
 
@@ -120,6 +120,8 @@ class AndroidResourceUnit(base.TranslationUnit):
                         # non-significant newlines/tabs etc.
                         text[i-space_count:i] = ' '
                         i -= space_count - 1
+                        if strip and (i == 1 or c is EOF):
+                            del text[i-1]
                     space_count = 0
                 elif space_count == 1:
                     # At this point we have a single whitespace character,
@@ -129,6 +131,8 @@ class AndroidResourceUnit(base.TranslationUnit):
                     # make sure that this kind of whitespace is always a
                     # standard space.
                     text[i-1] = ' '
+                    if strip and not active_quote and (i == 1 or c is EOF):
+                        del text[i-1]
                     space_count = 0
                 else:
                     space_count = 0
@@ -230,6 +234,9 @@ class AndroidResourceUnit(base.TranslationUnit):
         if len(text) == 0:
             return ''
         text = text.replace('\\', '\\\\')
+        # This will add non intrusive real newlines to
+        # ones in translation improving readability of result
+        text = text.replace('\n', '\n\\n')
         text = text.replace('\t', '\\t')
         text = text.replace('\'', '\\\'')
         text = text.replace('"', '\\"')
@@ -258,7 +265,8 @@ class AndroidResourceUnit(base.TranslationUnit):
         if '<' in target:
             try:
                 # Try to handle it as legacy XML
-                newstring = etree.fromstring('<string>%s</string>' % target)
+                parser = etree.XMLParser(strip_cdata=False, resolve_entities=False)
+                newstring = etree.fromstring('<string>%s</string>' % target, parser)
             except Exception:
                 # Fallback to string with XML escaping
                 xmltarget.text = self.escape(target)
@@ -353,12 +361,12 @@ class AndroidResourceUnit(base.TranslationUnit):
 
             # Unescaping texts.
             if (cloned_target.text is not None):
-                cloned_target.text = self.unescape(cloned_target.text)
+                cloned_target.text = self.unescape(cloned_target.text, False)
             for xmlelement in cloned_target.iterdescendants():
                 if (xmlelement.text is not None):
-                    xmlelement.text = self.unescape(xmlelement.text)
+                    xmlelement.text = self.unescape(xmlelement.text, False)
                 if (xmlelement.tail is not None):
-                    xmlelement.tail = self.unescape(xmlelement.tail)
+                    xmlelement.tail = self.unescape(xmlelement.tail, False)
 
             # Grab root text (using a temporary xml element for text escaping)
             if (cloned_target.text is not None):
@@ -460,7 +468,7 @@ class AndroidResourceFile(lisa.LISAfile):
             xml.seek(0)
             posrc = xml.read()
             xml = posrc
-        parser = etree.XMLParser(strip_cdata=False)
+        parser = etree.XMLParser(strip_cdata=False, resolve_entities=False)
         self.document = etree.fromstring(xml, parser).getroottree()
         self._encoding = self.document.docinfo.encoding
         self.initbody()
