@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2005-2011 Zuza Software Foundation
@@ -23,11 +22,12 @@
 The official recommendation is to use the extention .xlf for XLIFF files.
 """
 
+import six
 from lxml import etree
 
 from translate.misc.multistring import multistring
+from translate.misc.xml_helpers import getXMLspace, setXMLlang, setXMLspace
 from translate.storage import base, lisa
-from translate.storage.lisa import getXMLspace
 from translate.storage.placeables.lisa import strelem_to_xml, xml_to_strelem
 from translate.storage.workflow import StateEnum as state
 
@@ -43,6 +43,46 @@ ID_SEPARATOR = u"\04"
 ID_SEPARATOR_SAFE = u"__%04__"
 
 
+# List of ASCII control codes which are unaccepted in XML.
+ASCII_CONTROL_CODES = [
+    '0000',  # Unicode Character 'NULL' (U+0000)
+    '0001',  # Unicode Character 'START OF HEADING' (U+0001)
+    '0002',  # Unicode Character 'START OF TEXT' (U+0002)
+    '0003',  # Unicode Character 'END OF TEXT' (U+0003)
+    '0004',  # Unicode Character 'END OF TRANSMISSION' (U+0004)
+    '0005',  # Unicode Character 'ENQUIRY' (U+0005)
+    '0006',  # Unicode Character 'ACKNOWLEDGE' (U+0006)
+    '0007',  # Unicode Character 'BELL' (U+0007), "\a" in Python
+    '0008',  # Unicode Character 'BACKSPACE' (U+0008), "\b" in Python
+    '000b',  # Unicode Character 'LINE TABULATION' (U+000B), "\v" in Python
+    '000c',  # Unicode Character 'FORM FEED (FF)' (U+000C), "\f" in Python
+    '000e',  # Unicode Character 'SHIFT OUT' (U+000E)
+    '000f',  # Unicode Character 'SHIFT IN' (U+000F)
+    '0010',  # Unicode Character 'DATA LINK ESCAPE' (U+0010)
+    '0011',  # Unicode Character 'DEVICE CONTROL ONE' (U+0011)
+    '0012',  # Unicode Character 'DEVICE CONTROL TWO' (U+0012)
+    '0013',  # Unicode Character 'DEVICE CONTROL THREE' (U+0013)
+    '0014',  # Unicode Character 'DEVICE CONTROL FOUR' (U+0014)
+    '0015',  # Unicode Character 'NEGATIVE ACKNOWLEDGE' (U+0015)
+    '0016',  # Unicode Character 'SYNCHRONOUS IDLE' (U+0016)
+    '0017',  # Unicode Character 'END OF TRANSMISSION BLOCK' (U+0017)
+    '0018',  # Unicode Character 'CANCEL' (U+0018)
+    '0019',  # Unicode Character 'END OF MEDIUM' (U+0019)
+    '001a',  # Unicode Character 'SUBSTITUTE' (U+001A)
+    '001b',  # Unicode Character 'ESCAPE' (U+001B)
+    '001c',  # Unicode Character 'INFORMATION SEPARATOR FOUR' (U+001C)
+    '001d',  # Unicode Character 'INFORMATION SEPARATOR THREE' (U+001D)
+    '001e',  # Unicode Character 'INFORMATION SEPARATOR TWO' (U+001E)
+    '001f',  # Unicode Character 'INFORMATION SEPARATOR ONE' (U+001F)
+]
+
+ASCII_CONTROL_CHARACTERS = {code: six.unichr(int(code, 16))
+                            for code in ASCII_CONTROL_CODES}
+
+ASCII_CONTROL_CHARACTERS_ESCAPES = {code: u'&#x%s;' % code.lstrip('0') or '0'
+                                    for code in ASCII_CONTROL_CODES}
+
+
 class xliffunit(lisa.LISAunit):
     """A single term in the xliff file."""
 
@@ -62,19 +102,19 @@ class xliffunit(lisa.LISAunit):
     S_SIGNED_OFF = state.FINAL
 
     statemap = {
-                "new": S_UNTRANSLATED + 1,
-                "needs-translation": S_NEEDS_TRANSLATION,
-                "needs-adaptation": S_NEEDS_TRANSLATION + 1,
-                "needs-l10n": S_NEEDS_TRANSLATION + 2,
-                "needs-review-translation": S_NEEDS_REVIEW,
-                "needs-review-adaptation": S_NEEDS_REVIEW + 1,
-                "needs-review-l10n": S_NEEDS_REVIEW + 2,
-                "translated": S_TRANSLATED,
-                "signed-off": S_SIGNED_OFF,
-                "final": S_SIGNED_OFF + 1,
-                }
+        "new": S_UNTRANSLATED + 1,
+        "needs-translation": S_NEEDS_TRANSLATION,
+        "needs-adaptation": S_NEEDS_TRANSLATION + 1,
+        "needs-l10n": S_NEEDS_TRANSLATION + 2,
+        "needs-review-translation": S_NEEDS_REVIEW,
+        "needs-review-adaptation": S_NEEDS_REVIEW + 1,
+        "needs-review-l10n": S_NEEDS_REVIEW + 2,
+        "translated": S_TRANSLATED,
+        "signed-off": S_SIGNED_OFF,
+        "final": S_SIGNED_OFF + 1,
+    }
 
-    statemap_r = dict((i[1], i[0]) for i in statemap.iteritems())
+    statemap_r = dict((i[1], i[0]) for i in six.iteritems(statemap))
 
     STATE = {
         S_UNTRANSLATED: (state.EMPTY, state.NEEDS_WORK),
@@ -89,7 +129,18 @@ class xliffunit(lisa.LISAunit):
         super(xliffunit, self).__init__(source, empty, **kwargs)
         if empty:
             return
-        lisa.setXMLspace(self.xmlelement, "preserve")
+        setXMLspace(self.xmlelement, "preserve")
+
+    def getNodeText(self, languageNode, xml_space="preserve"):
+        """Retrieves the term from the given :attr:`languageNode`."""
+        text = super(xliffunit, self).getNodeText(languageNode,
+                                                  xml_space=xml_space)
+        if text is not None:
+            # Unescape the unaccepted ASCII control characters.
+            for code, character in ASCII_CONTROL_CHARACTERS.items():
+                text = text.replace(ASCII_CONTROL_CHARACTERS_ESCAPES[code],
+                                    character)
+        return text
 
     def createlanguageNode(self, lang, text, purpose):
         """Returns an xml Element setup with given parameters."""
@@ -101,7 +152,13 @@ class xliffunit(lisa.LISAunit):
         assert purpose
         langset = etree.Element(self.namespaced(purpose))
         # TODO: check language
-        #lisa.setXMLlang(langset, lang)
+        #setXMLlang(langset, lang)
+
+        # Escape the unaccepted ASCII control characters.
+        for code in ASCII_CONTROL_CODES:
+            text = text.replace(
+                six.unichr(int(code, 16)),
+                u'&#x%s;' % code.lstrip('0') or '0')
 
         langset.text = text
         return langset
@@ -112,13 +169,13 @@ class xliffunit(lisa.LISAunit):
         target = None
         nodes = []
         try:
-            source = self.xmlelement.iterchildren(self.namespaced(self.languageNode)).next()
-            target = self.xmlelement.iterchildren(self.namespaced('target')).next()
+            source = next(self.xmlelement.iterchildren(self.namespaced(self.languageNode)))
+            target = next(self.xmlelement.iterchildren(self.namespaced('target')))
             nodes = [source, target]
         except StopIteration:
             if source is not None:
                 nodes.append(source)
-            if not target is None:
+            if target is not None:
                 nodes.append(target)
         return nodes
 
@@ -168,11 +225,13 @@ class xliffunit(lisa.LISAunit):
 
     def get_rich_target(self, lang=None):
         """retrieves the "target" text (second entry), or the entry in the
-        specified language, if it exists"""
+        specified language, if it exists
+        """
         if self._rich_target is None:
             self._rich_target = [
                 xml_to_strelem(self.get_target_dom(lang),
-                getXMLspace(self.xmlelement, self._default_xml_space))
+                               getXMLspace(self.xmlelement,
+                                           self._default_xml_space))
             ]
         return self._rich_target
     rich_target = property(get_rich_target, set_rich_target)
@@ -187,12 +246,12 @@ class xliffunit(lisa.LISAunit):
 
         # TODO: support adding a source tag ad match quality attribute.  At the
         # source tag is needed to inject fuzzy matches from a TM.
-        if isinstance(txt, str):
+        if isinstance(txt, bytes):
             txt = txt.decode("utf-8")
         alttrans = etree.SubElement(self.xmlelement, self.namespaced("alt-trans"))
-        lisa.setXMLspace(alttrans, "preserve")
+        setXMLspace(alttrans, "preserve")
         if sourcetxt:
-            if isinstance(sourcetxt, str):
+            if isinstance(sourcetxt, bytes):
                 sourcetxt = sourcetxt.decode("utf-8")
             altsource = etree.SubElement(alttrans, self.namespaced("source"))
             altsource.text = sourcetxt
@@ -203,11 +262,12 @@ class xliffunit(lisa.LISAunit):
         if origin:
             alttrans.set("origin", origin)
         if lang:
-            lisa.setXMLlang(alttrans, lang)
+            setXMLlang(alttrans, lang)
 
     def getalttrans(self, origin=None):
         """Returns <alt-trans> for the given origin as a list of units. No
-        origin means all alternatives."""
+        origin means all alternatives.
+        """
         translist = []
         for node in self.xmlelement.iterdescendants(self.namespaced("alt-trans")):
             if self.correctorigin(node, origin):
@@ -218,14 +278,14 @@ class xliffunit(lisa.LISAunit):
                 # the source tag is optional
                 sourcenode = node.iterdescendants(self.namespaced("source"))
                 try:
-                    newunit.source = lisa.getText(sourcenode.next(),
+                    newunit.source = lisa.getText(next(sourcenode),
                                                   getXMLspace(node, self._default_xml_space))
                 except StopIteration:
                     pass
 
                 # must have one or more targets
                 targetnode = node.iterdescendants(self.namespaced("target"))
-                newunit.target = lisa.getText(targetnode.next(),
+                newunit.target = lisa.getText(next(targetnode),
                                               getXMLspace(node, self._default_xml_space))
                 # TODO: support multiple targets better
                 # TODO: support notes in alt-trans
@@ -247,7 +307,7 @@ class xliffunit(lisa.LISAunit):
             text = text.strip()
         if not text:
             return
-        if isinstance(text, str):
+        if isinstance(text, bytes):
             text = text.decode("utf-8")
         note = etree.SubElement(self.xmlelement, self.namespaced("note"))
         note.text = text
@@ -266,7 +326,10 @@ class xliffunit(lisa.LISAunit):
         # TODO: consider using xpath to construct initial_list directly
         # or to simply get the correct text from the outset (just remember to
         # check for duplication.
-        initial_list = [lisa.getText(note, getXMLspace(self.xmlelement, self._default_xml_space)) for note in note_nodes if self.correctorigin(note, origin)]
+        initial_list = [lisa.getText(note,
+                                     getXMLspace(self.xmlelement,
+                                                 self._default_xml_space))
+                        for note in note_nodes if self.correctorigin(note, origin)]
 
         # Remove duplicate entries from list:
         dictset = {}
@@ -359,7 +422,8 @@ class xliffunit(lisa.LISAunit):
     def markreviewneeded(self, needsreview=True, explanation=None):
         """Marks the unit to indicate whether it needs review.
 
-        Adds an optional explanation as a note."""
+        Adds an optional explanation as a note.
+        """
         state_id = self.get_state_id()
         if needsreview and state_id != self.S_NEEDS_REVIEW:
             self.set_state_n(self.S_NEEDS_REVIEW)
@@ -417,21 +481,21 @@ class xliffunit(lisa.LISAunit):
     def getid(self):
         uid = u""
         try:
-            filename = self.xmlelement.iterancestors(self.namespaced('file')).next().get('original')
+            filename = next(self.xmlelement.iterancestors(self.namespaced('file'))).get('original')
             if filename:
                 uid = filename + ID_SEPARATOR
         except StopIteration:
             # unit has no proper file ancestor, probably newly created
             pass
         # hide the fact that we sanitize ID_SEPERATOR
-        uid += unicode(self.xmlelement.get("id") or u"").replace(ID_SEPARATOR_SAFE, ID_SEPARATOR)
+        uid += six.text_type(self.xmlelement.get("id") or u"").replace(ID_SEPARATOR_SAFE, ID_SEPARATOR)
         return uid
 
     def addlocation(self, location):
         self.setid(location)
 
     def getlocations(self):
-        id_attr = unicode(self.xmlelement.get("id") or u"")
+        id_attr = six.text_type(self.xmlelement.get("id") or u"")
         # XLIFF files downloaded from PO projects in Pootle
         # might have id equal to .source, so let's avoid
         # that:
@@ -441,7 +505,8 @@ class xliffunit(lisa.LISAunit):
 
     def createcontextgroup(self, name, contexts=None, purpose=None):
         """Add the context group to the trans-unit with contexts a list with
-        (type, text) tuples describing each context."""
+        (type, text) tuples describing each context.
+        """
         assert contexts
         group = etree.Element(self.namespaced("context-group"))
         # context-group tags must appear at the start within <group>
@@ -455,7 +520,7 @@ class xliffunit(lisa.LISAunit):
         if purpose:
             group.set("purpose", purpose)
         for type, text in contexts:
-            if isinstance(text, str):
+            if isinstance(text, bytes):
                 text = text.decode("utf-8")
             context = etree.SubElement(group, self.namespaced("context"))
             context.text = text
@@ -507,11 +572,12 @@ class xliffunit(lisa.LISAunit):
     @classmethod
     def multistring_to_rich(cls, mstr):
         """Override :meth:`TranslationUnit.multistring_to_rich` which is used
-        by the ``rich_source`` and ``rich_target`` properties."""
+        by the ``rich_source`` and ``rich_target`` properties.
+        """
         strings = mstr
         if isinstance(mstr, multistring):
             strings = mstr.strings
-        elif isinstance(mstr, basestring):
+        elif isinstance(mstr, six.string_types):
             strings = [mstr]
 
         return [xml_to_strelem(s) for s in strings]
@@ -519,12 +585,14 @@ class xliffunit(lisa.LISAunit):
     @classmethod
     def rich_to_multistring(cls, elem_list):
         """Override :meth:`TranslationUnit.rich_to_multistring` which is used
-        by the ``rich_source`` and ``rich_target`` properties."""
-        return multistring([unicode(elem) for elem in elem_list])
+        by the ``rich_source`` and ``rich_target`` properties.
+        """
+        return multistring([six.text_type(elem) for elem in elem_list])
 
 
 class xlifffile(lisa.LISAfile):
     """Class representing a XLIFF file store."""
+
     UnitClass = xliffunit
     Name = "XLIFF Translation File"
     Mimetypes = ["application/x-xliff", "application/x-xliff+xml"]
@@ -563,7 +631,7 @@ class xlifffile(lisa.LISAfile):
         if self._filename:
             filenode = self.getfilenode(self._filename, createifmissing=True)
         else:
-            filenode = self.document.getroot().iterchildren(self.namespaced('file')).next()
+            filenode = next(self.document.getroot().iterchildren(self.namespaced('file')))
         self.body = self.getbodynode(filenode, createifmissing=True)
 
     def addheader(self):
@@ -572,8 +640,9 @@ class xlifffile(lisa.LISAfile):
 
     def createfilenode(self, filename, sourcelanguage=None,
                        targetlanguage=None, datatype='plaintext'):
-        """creates a filenode with the given filename. All parameters
-        are needed for XLIFF compliance."""
+        """creates a filenode with the given filename. All parameters are
+        needed for XLIFF compliance.
+        """
         if sourcelanguage is None:
             sourcelanguage = self.sourcelanguage
         if targetlanguage is None:
@@ -609,7 +678,7 @@ class xlifffile(lisa.LISAfile):
         """returns all filenames in this XLIFF file"""
         filenodes = self.document.getroot().iterchildren(self.namespaced("file"))
         filenames = [self.getfilename(filenode) for filenode in filenodes]
-        filenames = filter(None, filenames)
+        filenames = list(filter(None, filenames))
         if len(filenames) == 1 and filenames[0] == '':
             filenames = []
         return filenames
@@ -639,31 +708,32 @@ class xlifffile(lisa.LISAfile):
     def setsourcelanguage(self, language):
         if not language:
             return
-        filenode = self.document.getroot().iterchildren(self.namespaced('file')).next()
+        filenode = next(self.document.getroot().iterchildren(self.namespaced('file')))
         filenode.set("source-language", language)
 
     def getsourcelanguage(self):
-        filenode = self.document.getroot().iterchildren(self.namespaced('file')).next()
+        filenode = next(self.document.getroot().iterchildren(self.namespaced('file')))
         return filenode.get("source-language")
     sourcelanguage = property(getsourcelanguage, setsourcelanguage)
 
     def settargetlanguage(self, language):
         if not language:
             return
-        filenode = self.document.getroot().iterchildren(self.namespaced('file')).next()
+        filenode = next(self.document.getroot().iterchildren(self.namespaced('file')))
         filenode.set("target-language", language)
 
     def gettargetlanguage(self):
-        filenode = self.document.getroot().iterchildren(self.namespaced('file')).next()
+        filenode = next(self.document.getroot().iterchildren(self.namespaced('file')))
         return filenode.get("target-language")
     targetlanguage = property(gettargetlanguage, settargetlanguage)
 
     def getdatatype(self, filename=None):
         """Returns the datatype of the stored file. If no filename is given,
-        the datatype of the first file is given."""
+        the datatype of the first file is given.
+        """
         if filename:
             node = self.getfilenode(filename)
-            if not node is None:
+            if node is not None:
                 return node.get("datatype")
         else:
             filenames = self.getfilenames()
@@ -682,7 +752,7 @@ class xlifffile(lisa.LISAfile):
         """
         if filename:
             node = self.getfilenode(filename)
-            if not node is None:
+            if node is not None:
                 return node.get("date")
         else:
             filenames = self.getfilenames()
@@ -692,7 +762,8 @@ class xlifffile(lisa.LISAfile):
 
     def removedefaultfile(self):
         """We want to remove the default file-tag as soon as possible if we
-        know if still present and empty."""
+        know if still present and empty.
+        """
         filenodes = list(self.document.getroot().iterchildren(self.namespaced("file")))
         if len(filenodes) > 1:
             for filenode in filenodes:
@@ -706,7 +777,7 @@ class xlifffile(lisa.LISAfile):
         # TODO: Deprecated?
         headernode = filenode.iterchildren(self.namespaced("header"))
         try:
-            return headernode.next()
+            return next(headernode)
         except StopIteration:
             pass
         if not createifmissing:
@@ -718,7 +789,7 @@ class xlifffile(lisa.LISAfile):
         """finds the body node for the given filenode"""
         bodynode = filenode.iterchildren(self.namespaced("body"))
         try:
-            return bodynode.next()
+            return next(bodynode)
         except StopIteration:
             pass
         if not createifmissing:
@@ -727,9 +798,10 @@ class xlifffile(lisa.LISAfile):
         return bodynode
 
     def addsourceunit(self, source, filename="NoName", createifmissing=False):
-        """adds the given trans-unit to the last used body node if the
-        filename has changed it uses the slow method instead (will
-        create the nodes required if asked). Returns success"""
+        """adds the given trans-unit to the last used body node if the filename
+        has changed it uses the slow method instead (will create the nodes
+        required if asked). Returns success
+        """
         if self._filename != filename:
             if not self.switchfile(filename, createifmissing):
                 return None
@@ -773,9 +845,9 @@ class xlifffile(lisa.LISAfile):
             group.set("restype", restype)
         return group
 
-    def __str__(self):
+    def serialize(self, out):
         self.removedefaultfile()
-        return super(xlifffile, self).__str__()
+        super(xlifffile, self).serialize(out)
 
     @classmethod
     def parsestring(cls, storestring):
@@ -784,8 +856,8 @@ class xlifffile(lisa.LISAfile):
         if xliff.units:
             header = xliff.units[0]
             if (("gettext-domain-header" in (header.getrestype() or "") or
-                 xliff.getdatatype() == "po") and
-                 cls.__name__.lower() != "poxlifffile"):
+                xliff.getdatatype() == "po") and
+                cls.__name__.lower() != "poxlifffile"):
                 from translate.storage import poxliff
                 xliff = poxliff.PoXliffFile.parsestring(storestring)
         return xliff
