@@ -362,8 +362,10 @@ def convertpo(inputfile, outputfile, templatefile, format=None, rewritestyle=Non
 def main():
     from translate.convert import convert
     formats = {
-        "po": ("po", convertpo), "pot": ("po", convertpo),
+        "po": ("po", convertpo),
+        "pot": ("po", convertpo),
         "xlf": ("xlf", convertpo),
+        "xliff": ("xliff", convertpo),
         "tmx": ("tmx", convertpo),
     }
     parser = convert.ConvertOptionParser(formats, description=__doc__)
